%
%  This is a simple code to demonstrate classical relative relocation using
%    the North Korean events and data from surrounding stations available
%    at IRIS as a highlight of what one can do with data available from IRIS. 
%    These are not definitive results and are merely an exercise.  This 
%    assumes all arrivals are Pn with a fixed velocity.  The results will
%    vary with choice of Pn velocity, which stations are selected and the 
%    relative travel time shift at each station.  No guarantees or support
%    are given.
%
%  Alex Hutko, IRIS DMC, Feb 2013
%

clear all;
fig2=figure('units','pixels','outerposition',[50 50 800 300 ],'paperpositionmode','auto');  %   left up width height
set(gcf, 'Color', [1,1,1]);

set(0,'DefaultTextFontSize', 6)
set(0,'DefaultAxesFontSize', 8)

%
%  Here is where the user can add/remove/adjust observations, which will affect results.
%  StatAzi2006 are the station azimuths for the 2006/2009 seismogram pairs.
%  StatAzi2013 are the station azimuths for the 2013/2009 seismogram pairs.
%  StatShift2006 are the cross-correlation based shifts for the 2006/2009 seismogram pairs.
%  StatShift2013 are the cross-correlation based shifts for the 2013/2009 seismogram pairs.
%

StatAzi2006 = [ 117 6 207 ];
StatShift2006 = [ -0.22 0.165 0.16 ];

StatAzi2013 = [ 169 55 121 6 324 267 ];
StatShift2013 = [ -0.54 -0.39 -0.45 -0.42 -0.45 -0.44 ];

velocity=7.8;    %------ assumed Pn velocity

%----------- demean the shifts ---------

StatShift2013 = StatShift2013 - mean(StatShift2013);
StatShift2006 = StatShift2006 - mean(StatShift2006);

%------------- set grid size -------------

GridMaxKM=3;      %----- user can adjust

%--------- these do not need adjusting ----------

maxshifts = [ max(abs(StatShift2006))  max(abs(StatShift2013)) ];
ResidMax = max(maxshifts)*1.5;

%---------------- find best fitting 2006 solution -----------
%  Find the sinusoid as f(azimuth around the source) that best fits
%  the observed residuals.  The 2009 event is assumed to be the
%  reference location.
%

azi=StatAzi2006;
shift=StatShift2006;
shift=shift-mean(shift);

errsummin=9999999;
for x=-GridMaxKM:0.1:GridMaxKM
   for y=-GridMaxKM:0.1:GridMaxKM
      dist=sqrt((x^2)+(y^2));
      tshift=dist/velocity;
      for i=1:360
         sazi=(180/pi)*atan(y/x);
         if ( y < 0 )
            sazi=sazi+180;
         end
         if ( x < 0 )
            sazi=sazi+360;
         end
         amp(i)=-tshift*cos((sazi-i)*pi/180);
         phase(i)=i;
      end
     for i=1:length(azi)
        err(i)=(amp(azi(i))-shift(i))^2;
     end
     errsum=sum(err);
     if (errsum < errsummin )
        xbest2006=x;
        ybest2006=y;
        errsummin=errsum;
     end
   end
end

%---------------- find best fitting 2013 solution -----------

azi=StatAzi2013;
shift=StatShift2013;

errsummin=9999999;
for x=-GridMaxKM:0.1:GridMaxKM
   for y=-GridMaxKM:0.1:GridMaxKM
      dist=sqrt((x^2)+(y^2));
      tshift=dist/velocity;
      for i=1:360
         sazi=(180/pi)*atan(y/x);
         if ( y < 0 )
            sazi=sazi+180;
         end
         if ( x < 0 )
            sazi=sazi+360;
         end
         amp(i)=-tshift*cos((sazi-i)*pi/180);
         phase(i)=i;
      end
     for i=1:length(azi)
        err(i)=(amp(azi(i))-shift(i))^2;
     end
     errsum=sum(err);
     if (errsum < errsummin )
        xbest2013=x;
        ybest2013=y;
        errsummin=errsum;
     end
   end
end

%--------------- plot relative locations of all events (Left panel) -------------------
%
% Also plotted for reference are solutions from Neil D Selby (BSSA 2009):
%  "The 2009 test is found to have occurred about 1.8±0.8 km to the west and 0.4±0.6 km to the north of the 2006 test"
%
% And the solution from Hutko, 2009 using Hinet data only ( http://es.ucsc.edu/~ahutko/NKorea ):
%   2009 is ~2.5km to the west and ~1.5km to the north of 2006.
%

subplot('Position',[0.08 0.15 0.23 0.75 ])  %   left up width height

%----- 2009 is used as the master location
plot(0,0,'rp','markersize',11,'markerfacecolor','r')
title('Locations of 2006 and 2013 events relative to 2009 event')
xlabel('km E-W relative to 2009 event')
ylabel('km N-S relative to 2009 event')
axis([ -GridMaxKM*1.1  GridMaxKM*1.1  -GridMaxKM*1.1  GridMaxKM*1.1  ]);

%----- 2013 this relocation
hold on
plot(xbest2013,ybest2013,'bo','markersize',11,'markerfacecolor','b')
text(-1.2,-0.4,'2013','color','b','backgroundcolor','w')
grid on

%----- 2006 this relocation
hold on
plot(xbest2006,ybest2006,'ko','markersize',11,'markerfacecolor','k')
text(-0.2,-2.4,'2006','color','k','backgroundcolor','w')
grid on

%------- selby 2006
x=1.8;
y=-0.4;
plot(x,y,'k^','markersize',11,'markerfacecolor',[0.5 0.5 0.5])
text(2.1,-0.3,'2006 Selby','backgroundcolor','w')

%------- Hutko Hinet 2006
x=2.5;
y=-1.5;
plot(x,y,'kv','markersize',11,'markerfacecolor',[0.5 0.5 0.5])
text(1.3,-1.8,'2006 Hutko (Hinet)','backgroundcolor','w')


%---------------- plot best fitting 2006 solution (middle panel) -----------

azi=StatAzi2006;
shift=StatShift2006;
shift=shift-mean(shift);

x=xbest2006;
y=ybest2006;
dist=sqrt((x^2)+(y^2));
tshift=dist/velocity;
for i=1:360
   sazi=(180/pi)*atan(y/x);
   if ( y < 0 )
      sazi=sazi+180;
   end
   if ( x < 0 )
      sazi=sazi+360;
   end
   amp(i)=-tshift*cos((sazi-i)*pi/180);
   phase(i)=i;
end

subplot('Position',[0.4 0.15 0.23 0.75 ])  %   left up width height
plot(azi,shift,'ok','markersize',9,'markerfacecolor','k')
axis([ 0 360 -ResidMax ResidMax ])
grid on
hold on
plot(phase,amp,'k')
ylabel('Travel time residual (sec)')
xlabel('Azimuth from event to station')
text(150,0.25,'2006','backgroundcolor','w','fontsize',10)

%---------------- plot best fitting 2013 solution (right panel) -----------

azi=StatAzi2013;
shift=StatShift2013;
shift=shift-mean(shift);

x=xbest2013;
y=ybest2013;
dist=sqrt((x^2)+(y^2));
tshift=dist/velocity;
for i=1:360
   sazi=(180/pi)*atan(y/x);
   if ( y < 0 )
      sazi=sazi+180;
   end
   if ( x < 0 )
      sazi=sazi+360;
   end
   amp(i)=-tshift*cos((sazi-i)*pi/180);
   phase(i)=i;
end

subplot('Position',[0.72 0.15 0.23 0.75 ])  %   left up width height
plot(azi,shift,'ob','markersize',9,'markerfacecolor','b')
axis([ 0 360 -ResidMax ResidMax ])
grid on
hold on
plot(phase,amp,'b')
ylabel('Travel time residual (sec)')
xlabel('Azimuth from event to station')
text(-350,ResidMax*1.1,'                      Residuals asssuming 2009 location                 ','fontsize',8)
text(150,0.25,'2013','color','b','backgroundcolor','w','fontsize',10)

%  print -dpng Relocation_Exercise.png


